@@ -5,17 +5,16 @@ from trytond.pool import Pool, PoolMeta
 from trytond.modules.analytic_account import AnalyticMixin
 
 __all__ = ['SaleLine', 'AnalyticAccountEntry']
-__metaclass__ = PoolMeta
 
 
 class SaleLine(AnalyticMixin):
     __name__ = 'sale.line'
 
-    def get_invoice_line(self, invoice_type):
+    def get_invoice_line(self):
         pool = Pool()
         AnalyticAccountEntry = pool.get('analytic.account.entry')
 
-        invoice_lines = super(SaleLine, self).get_invoice_line(invoice_type)
+        invoice_lines = super(SaleLine, self).get_invoice_line()
         for invoice_line in invoice_lines:
             new_entries = AnalyticAccountEntry.copy(self.analytic_accounts,
                 default={
@@ -26,6 +25,7 @@ class SaleLine(AnalyticMixin):
 
 
 class AnalyticAccountEntry:
+    __metaclass__ = PoolMeta
     __name__ = 'analytic.account.entry'
 
     @classmethod
